CARBS's documentation
=====================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api
   usage
   toolchain
   cicd
   Test Coverage Report <./reports/coverage/index.html#http://>
   Test Results Report <./reports/junit/junit.html#http://>
   LAGER Homepage <http://lager.ua.edu/>
   References
   license


.. include:: ../../README.rst
    :start-after: BEGIN LINKS INCLUDE
    :end-before: END LINKS INCLUDE


|Open in Dev Containers| |Test Status| |Test Cov|

A python package for Command & control (C2) of Autonomous Random finite set- (RFS-) Based Swarms (CARBS) developed developed by the Laboratory for Autonomy, GNC, and Estimation Research (LAGER) at the University of Alabama (UA). To get started using this package simply run :code:`pip install carbs`. This package was previously named CARBS (Command control & information of Autonomous Swarms Employing Random finite sets), and before that GASUR (Guidance navigation and control of Autonomous Swarms Using Random finite sets) but neither had releases on PyPI. Some references may exist to those packages but they have been migrated to CARBS.


.. include:: ../../README.rst
    :start-after: BEGIN CITE INCLUDE
    :end-before: END CITE INCLUDE


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
